@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from ._standards.cnae2 import CNAE2, CNAE2_to_ISIC4
 from ._standards.isic3 import ISIC3, ISIC3_to_ISIC31
 from ._standards.isic4 import ISIC4
 from ._standards.isic31 import ISIC31, ISIC31_to_ISIC4
@@ -7,7 +8,7 @@ from ._standards.ksic10 import KSIC10, KSIC10_to_ISIC4
 from ._standards.nace2 import NACE2, NACE2_to_ISIC4
 from ._standards.naics2017 import NAICS2017, NAICS2017_to_ISIC4
 from ._standards.skd2002 import SKD2002, SKD2002_to_NACE2, SKD2002_to_SKD2008
-from ._standards.skd2008 import SKD2008
+from ._standards.skd2008 import SKD2008, SKD2008_to_SKD2002
 from ._standards.skis2010 import SKIS2010
 from ._standards.tsic2552 import TSIC2552, TSIC2552_to_ISIC3
 from .types import ComposedGraph, Standards
@@ -22,7 +23,8 @@ ToISIC4 = ComposedGraph(
         TSIC2552_to_ISIC3,
         JSIC13_to_ISIC4,
         KSIC10_to_ISIC4,
+        SKD2008_to_SKD2002,
         SKD2002_to_NACE2,
-        SKD2002_to_SKD2008,
+        CNAE2_to_ISIC4,
     ],
 )
